
.field-images select[name=images] {
    display: none; !important;
}

.files {
    width: 100%;
}

.files .file-preview {
    border: 1px solid #adadad;
    width: 100px;
    height: 100px;
    display: block;
    float: left;
    margin-right: 10px;
    margin-bottom: 10px;
}

.files .file-preview img {
    max-width: 98px;
    max-height: 98px;
}

.drop-section {
    width: 200px;
    height: 150px;
    padding: 20px;
    float: left;
    border: 2px solid rgba(0, 0, 0, 0.3);
    margin-right: 10px;
    text-align: center;
    background: #fff;
}
